@@ -23,6 +23,6 @@ def infer(img, model_pt):
     with torch.no_grad():
         predicts = model(input_batch)
     outs = decodePredicts(predicts, (1536, 512), 690)
-    outs = outs.permute((0, 2, 3, 1).numpy().astype(np.uint8))
-
-    return outs
+    outs = outs.permute(0, 2, 3, 1).numpy().astype(np.uint8)
+    outs1 = outs.squeeze(0)
+    return outs1
